@@ -111,7 +111,7 @@ MODIStsp_vrt_create <- function(out_prod_folder, meta_band, file_prefixes,
         }
 
         # Write the ENVI meta file
-        meta_dir <- file.path(out_prod_folder, "Time_Series", "ENVI_META")
+        meta_dir <- file.path(out_prod_folder, "Time_Series", "ENVI_META", sens_sel, meta_band)
         dir.create(meta_dir, showWarnings = FALSE, recursive = TRUE)
         meta_filename <- file.path(meta_dir, paste(file_prefix, meta_band, doy_min, year_min,
                                                    doy_max, year_max, "META.dat", sep = "_"))  # define fileneame for meta
@@ -151,11 +151,11 @@ MODIStsp_vrt_create <- function(out_prod_folder, meta_band, file_prefixes,
       # Write a gdal vrt file
       if (ts_format == "GDAL vrt Files" | ts_format == "ENVI and GDAL") {
 
-        meta_dir <- file.path(out_prod_folder, "Time_Series", "GDAL_vrt")
+        meta_dir <- file.path(out_prod_folder, "Time_Series", "GDAL", sens_sel, meta_band)
         dir.create(meta_dir, showWarnings = F, recursive = TRUE)
         meta_filename <- file.path(meta_dir, paste(file_prefix, meta_band, doy_min,
                                                    year_min, doy_max, year_max,
-                                                   "GDAL_vrt.vrt",
+                                                   "GDAL.vrt",
                                                    sep = "_"))
         gdalbuildvrt(out_meta_files, meta_filename, separate = TRUE, 
                      srcnodata = nodata_value, vrtnodata = nodata_value)
@@ -165,7 +165,7 @@ MODIStsp_vrt_create <- function(out_prod_folder, meta_band, file_prefixes,
       # If "rts" selected, also build Raster Time Series "R" output files
       if (rts == "Yes") {
 
-        meta_dir <- file.path(out_prod_folder, "Time_Series/RData")
+        meta_dir <- file.path(out_prod_folder, "Time_Series", "RData", sens_sel, meta_band)
         dir.create(meta_dir, showWarnings = FALSE, recursive = TRUE)
         # raster_ts <- rts(out_meta_files,temp_dates)
         # NAvalue(raster_ts@raster) <- as.integer(nodata_value)
